@@ -21,19 +21,24 @@ This file is part of C.a.R. software.
  
  package rene.zirkel.dialogs;
 
-import java.awt.*;
+import java.awt.Frame;
 
 import rene.gui.CloseDialog;
-import rene.zirkel.help.Info;
 
-public class HelpCloseDialog extends CloseDialog
-{	Frame F;
-	public HelpCloseDialog (Frame f, String s, boolean modal)
-	{	super(f,s,modal);
-		F=f;
+public class HelpCloseDialog extends CloseDialog {
+	/**
+	 * 
+	 */
+	private static final long serialVersionUID = 1L;
+	Frame F;
+
+	public HelpCloseDialog(final Frame f, final String s, final boolean modal) {
+		super(f, s, modal);
+		F = f;
 	}
-	public void showHelp ()
-	{	Info.Subject=Subject;
-		Info id=new Info(F,true);
+
+	@Override
+	public void showHelp() {
+
 	}
 }
