@@ -23,20 +23,22 @@ This file is part of C.a.R. software.
 
 // file: ZirkelCanvas.java
 
-import java.awt.*;
+import java.awt.MenuItem;
 
 import rene.util.sort.SortObject;
 
-public class MacroItem
-	implements SortObject
-{	public MenuItem I;
+public class MacroItem implements SortObject {
+	public MenuItem I;
 	public Macro M;
 	public String Name;
-	public MacroItem (Macro m, MenuItem i)
-	{	M=m; I=i;
+
+	public MacroItem(final Macro m, final MenuItem i) {
+		M = m;
+		I = i;
 	}
-	public int compare (SortObject o) 
-	{	MacroItem mio=(MacroItem)o;
+
+	public int compare(final SortObject o) {
+		final MacroItem mio = (MacroItem) o;
 		return -mio.M.Name.compareTo(M.Name);
 	}
 }
